@@ -9,9 +9,11 @@ from __future__ import absolute_import, print_function
 
 import logging
 import sys
+from copy import deepcopy
 
 import click
 
+from libvcs._compat import PY2
 from libvcs.shortcuts import create_repo_from_pip_url
 
 from .__about__ import __version__
@@ -19,6 +21,9 @@ from .cli_defaultgroup import DefaultGroup
 from .config import filter_repos, find_config_files, load_configs
 from .log import DebugLogFormatter, RepoFilter, RepoLogFormatter
 
+if PY2:
+    FileNotFoundError = EnvironmentError
+
 MIN_ASYNC = 3  # minimum amount of repos to sync concurrently
 MAX_ASYNC = 8  # maximum processes to open:w
 
@@ -122,12 +127,40 @@ def progress_cb(output, timestamp):
 
 
 def update_repo(repo_dict):
-    repo_dict['pip_url'] = repo_dict.pop('url')
+    repo_dict = deepcopy(repo_dict)
+    if 'pip_url' not in repo_dict:
+        repo_dict['pip_url'] = repo_dict.pop('url')
     repo_dict['progress_callback'] = progress_cb
 
-    r = create_repo_from_pip_url(**repo_dict)
+    r = create_repo_from_pip_url(**repo_dict)  # Creates the repo object
 
-    r.update_repo()
+    remote_settings = repo_dict.get('remotes', [])
+    if not any(rs for rs in remote_settings if rs['remote_name'] == 'origin'):
+        remote_settings.append({'remote_name': 'origin', 'url': repo_dict['pip_url']})
+
+    for remote_setting in remote_settings:
+        config_remote_name = remote_setting['remote_name']  # From config file
+        try:
+            current_remote = r.remote(config_remote_name)
+        except FileNotFoundError:  # git repo doesn't exist yet, so cna't be outdated
+            break
+
+        if (
+            current_remote is not None
+            and current_remote.fetch_url != remote_setting['url']
+        ):
+            print(
+                'Updating remote {name} ({current_url}) with {new_url}'.format(
+                    name=config_remote_name,
+                    current_url=current_remote.fetch_url,
+                    new_url=remote_setting['url'],
+                )
+            )
+            r.set_remote(
+                name=config_remote_name, url=remote_setting['url'], overwrite=True
+            )
+    r.update_repo()  # Creates repo if not exists and fetches
+    return r
 
 
 cli.add_command(update)
