@@ -6,9 +6,7 @@ vcspull.config
 A lot of these items are todo.
 
 """
-
-from __future__ import (absolute_import, print_function, unicode_literals,
-                        with_statement)
+from __future__ import absolute_import, print_function, unicode_literals
 
 import fnmatch
 import glob
@@ -17,8 +15,9 @@ import os
 
 import kaptan
 
+from libvcs._compat import string_types
+
 from . import exc
-from ._compat import string_types
 from .util import CONFIG_DIR, update_dict
 
 log = logging.getLogger(__name__)
@@ -27,9 +26,11 @@ log = logging.getLogger(__name__)
 def expand_dir(_dir, cwd=os.getcwd()):
     """Return path with environmental variables and tilde ~ expanded.
 
-    :param dir:
-    :type dir: string
-    :rtype; string
+    :param _dir:
+    :type _dir: str
+    :param cwd: current working dir (for deciphering relative _dir paths)
+    :type cwd: str
+    :rtype; str
     """
     _dir = os.path.expanduser(os.path.expandvars(_dir))
     if not os.path.isabs(_dir):
@@ -45,6 +46,8 @@ def extract_repos(config, cwd=os.getcwd()):
 
     :param config: the repo config in :py:class:`dict` format.
     :type config: dict
+    :param cwd: current working dir (for deciphering relative paths)
+    :type cwd: str
     :rtype: list
 
     """
@@ -80,9 +83,7 @@ def extract_repos(config, cwd=os.getcwd()):
             '''
             if 'shell_command_after' in conf:
                 if isinstance(conf['shell_command_after'], string_types):
-                    conf['shell_command_after'] = [
-                        conf['shell_command_after']
-                    ]
+                    conf['shell_command_after'] = [conf['shell_command_after']]
 
             if 'name' not in conf:
                 conf['name'] = repo
@@ -96,10 +97,7 @@ def extract_repos(config, cwd=os.getcwd()):
             if 'remotes' in conf:
                 remotes = []
                 for remote_name, url in conf['remotes'].items():
-                    remotes.append({
-                        'remote_name': remote_name,
-                        'url': url
-                    })
+                    remotes.append({'remote_name': remote_name, 'url': url})
                 conf['remotes'] = sorted(
                     remotes, key=lambda x: sorted(x.get('remote_name'))
                 )
@@ -120,15 +118,12 @@ def find_home_config_files(filetype=['json', 'yaml']):
     if not has_yaml_config and not has_json_config:
         log.debug(
             'No config file found. Create a .vcspull.yaml or .vcspull.json'
-            ' in your $HOME directory. http://vcspull.rtfd.org for a'
+            ' in your $HOME directory. http://vcspull.git-pull.com for a'
             ' quickstart.'
         )
     else:
         if sum(filter(None, [has_json_config, has_yaml_config])) > int(1):
-            raise exc.MultipleRootConfigs(
-                'multiple configs found in home directory use only one.'
-                ' .yaml, .json.'
-            )
+            raise exc.MultipleConfigWarning()
         if has_yaml_config:
             configs.append(yaml_config)
         if has_json_config:
@@ -138,10 +133,7 @@ def find_home_config_files(filetype=['json', 'yaml']):
 
 
 def find_config_files(
-    path=['~/.vcspull'],
-    match=['*'],
-    filetype=['json', 'yaml'],
-    include_home=False
+    path=['~/.vcspull'], match=['*'], filetype=['json', 'yaml'], include_home=False
 ):
     """Return repos from a directory and match. Not recursive.
 
@@ -156,8 +148,6 @@ def find_config_files(
     :raises:
         - LoadConfigRepoConflict: There are two configs that have same path
           and name with different repo urls.
-        - NoConfigsFound: No configs found in home directory or ~/.vcspull
-          directory.
     :returns: list of absolute paths to config files.
     :rtype: list
 
@@ -194,8 +184,10 @@ def load_configs(files, cwd=os.getcwd()):
 
     :todo: Validate scheme, check for duplciate destinations, VCS urls
 
-    :param configs: paths to config file
-    :type path: list
+    :param files: paths to config file
+    :type files: list
+    :param cwd: current path (pass down for :func:`extract_repos`
+    :type cwd: str
     :returns: expanded config dict item
     :rtype: list of dict
     """
@@ -213,10 +205,8 @@ def load_configs(files, cwd=os.getcwd()):
         dupes = detect_duplicate_repos(repos, newrepos)
 
         if dupes:
-            msg = (
-                'repos with same path + different VCS detected!', dupes
-            )
-            raise Exception(msg)
+            msg = ('repos with same path + different VCS detected!', dupes)
+            raise exc.VCSPullException(msg)
         repos.extend(newrepos)
 
     return repos
@@ -243,31 +233,24 @@ def detect_duplicate_repos(repos1, repos2):
         return None
 
     path_dupe_repos.extend(
-        [r for r in repos2 if
-            any(r['repo_dir'] == p for p in path_duplicates)]
+        [r for r in repos2 if any(r['repo_dir'] == p for p in path_duplicates)]
     )
 
     if not path_dupe_repos:
         return None
 
     for n in path_dupe_repos:
-        currepo = next(
-            (r for r in repos1
-                if r['repo_dir'] == n['repo_dir']), None
-        )
+        currepo = next((r for r in repos1 if r['repo_dir'] == n['repo_dir']), None)
         if n['url'] != currepo['url']:
-            dupes += (n, currepo,)
+            dupes += (n, currepo)
     return dupes
 
 
-def in_dir(
-    config_dir=CONFIG_DIR,
-    extensions=['.yml', '.yaml', '.json']
-):
+def in_dir(config_dir=CONFIG_DIR, extensions=['.yml', '.yaml', '.json']):
     """Return a list of configs in ``config_dir``.
 
     :param config_dir: directory to search
-    :type config_dir: string
+    :type config_dir: str
     :param extensions: filetypes to check (e.g. ``['.yaml', '.json']``).
     :type extensions: list
     :rtype: list
@@ -276,8 +259,7 @@ def in_dir(
     configs = []
 
     for filename in os.listdir(config_dir):
-        if is_config_file(filename, extensions) and \
-           not filename.startswith('.'):
+        if is_config_file(filename, extensions) and not filename.startswith('.'):
             configs.append(filename)
 
     return configs
@@ -308,19 +290,11 @@ def filter_repos(config, repo_dir=None, vcs_url=None, name=None):
 
     if vcs_url:
         repo_list.extend(
-            r for r in config if fnmatch.fnmatch(
-                r.get('url', r.get('repo')),
-                vcs_url
-            )
+            r for r in config if fnmatch.fnmatch(r.get('url', r.get('repo')), vcs_url)
         )
 
     if name:
-        repo_list.extend(
-            [r for r in config if fnmatch.fnmatch(
-                r.get('name'),
-                name
-            )]
-        )
+        repo_list.extend([r for r in config if fnmatch.fnmatch(r.get('name'), name)])
 
     return repo_list
 
@@ -329,12 +303,11 @@ def is_config_file(filename, extensions=['.yml', '.yaml', '.json']):
     """Return True if file has a valid config file type.
 
     :param filename: filename to check (e.g. ``mysession.json``).
-    :type filename: string
+    :type filename: str
     :param extensions: filetypes to check (e.g. ``['.yaml', '.json']``).
-    :type extensions: list or string
+    :type extensions: list or str
     :rtype: bool
 
     """
-    extensions = [extensions] if isinstance(
-        extensions, string_types) else extensions
+    extensions = [extensions] if isinstance(extensions, string_types) else extensions
     return any(filename.endswith(e) for e in extensions)
